# -*- coding: utf-8 -*-
"""
Chordix
=======
The main function of Chordix is incomplete now.

Provides
--------
1. ...

- As midi file regard C4 as 60, so in Chordix, we consider C4's pitch space as 60 instead of 0.

To import `Chordix`::

  >>> import Chordix

To search for documents containing a keyword, do::

  >>> Chordix.lookfor('keyword')

Available subpackages
---------------------
...

Some naming regulations:
------------------------
...
"""

# no need to compatible with python2
from __future__ import annotations

from typing import Literal

try:
    ...
except ImportError:
    ...


def lookfor(what: str) -> None:
    """
    Search docstrings for occurrences of a given word or phrase.
    Prints results to stdout.
    """
    return None
